@@ -15,6 +15,7 @@
 # @license: http://www.apache.org/licenses/LICENSE-2.0
 # @author: Kevin Crouse (krcrouse@gmail.com)
 
+import os
 import re
 import warnings
 import datetime
@@ -180,7 +181,6 @@ class ServiceClient():
     services = googleapps.ServiceManager()
     default_api = None
     default_api_version = None
-    default_scope = None
     debug=False
     debug_commit=False
 
@@ -288,22 +288,23 @@ class ServiceClient():
         #TODO: we either needto change the class variables to 'api' and 'api_version' or handle instance variables here.
         return(self.get_service(self.default_api, self.default_api_version))
 
+
     @classmethod
     def get_service(cls, api=None, api_version=None):
         if api:
             if not api_version and api == cls.api:
-                return(cls.services.load_service(cls.default_api, cls.default_api_version, cls.default_scope))
+                return(cls.services.load_service(cls.default_api, cls.default_api_version))
 
             return(cls.services.load_service(api, api_version))
         else:
-            return(cls.services.load_service(cls.default_api, cls.default_api_version, cls.default_scope))
+            return(cls.services.load_service(cls.default_api, cls.default_api_version))
 
 
     def _send_request(self, request):
         return(self.__class__.make_class_request(request, object=self, attempt_recover=self.attempt_recover, retry_count=self.retry_count, debug=self.debug))
 
     @classmethod
-    def make_class_request(cls, request, object=None, debug=None, attempt_recover=True, retry_count=4):
+    def make_class_request(cls, request, object=None, debug=None, attempt_recover=True, retry_count=3):
 
         service = cls.get_service(request.api, request.api_version)
 
